@@ -51,10 +51,10 @@ struct _ECalBackendExchangeTasksPrivate {
 	icalcomponent *icalcomp;
 
 	/* All the objects in the calendar, hashed by UID.  The
-         * hash key *is* the uid returned by cal_component_get_uid(); it is not
-         * copied, so don't free it when you remove an object from the hash
-         * table. Each item in the hash table is a ECalBackendExchangeTasksObject.
-         */
+ *       * hash key *is* the uid returned by cal_component_get_uid(); it is not
+ *       * copied, so don't free it when you remove an object from the hash
+ *       * table. Each item in the hash table is a ECalBackendExchangeTasksObject.
+ *       */
         GHashTable *comp_uid_hash;
 
 	GList *comp;
@@ -66,11 +66,16 @@ struct _ECalBackendExchangeTasksPrivate {
 	gint dummy;
 };
 
-#define PARENT_TYPE E_TYPE_CAL_BACKEND_EXCHANGE
-static ECalBackendExchange *parent_class = NULL;
+G_DEFINE_TYPE (
+	ECalBackendExchangeTasks,
+	e_cal_backend_exchange_tasks,
+	E_TYPE_CAL_BACKEND_EXCHANGE)
 
 static void
-get_from (ECalBackendSync *backend, ECalComponent *comp, gchar **from_name, gchar **from_addr)
+get_from (ECalBackendSync *backend,
+          ECalComponent *comp,
+          gchar **from_name,
+          gchar **from_addr)
 {
 	if (!g_ascii_strcasecmp (e_cal_backend_exchange_get_owner_email (backend), exchange_account_get_email_id (E_CAL_BACKEND_EXCHANGE (backend)->account)))
 		e_cal_backend_exchange_get_from (backend, comp, from_name, from_addr);
@@ -96,7 +101,8 @@ get_from (ECalBackendSync *backend, ECalComponent *comp, gchar **from_name, gcha
 }
 
 static void
-set_uid (E2kProperties *props, ECalComponent *comp)
+set_uid (E2kProperties *props,
+         ECalComponent *comp)
 {
 	const gchar *uid;
 
@@ -105,7 +111,8 @@ set_uid (E2kProperties *props, ECalComponent *comp)
 }
 
 static void
-set_summary (E2kProperties *props, ECalComponent *comp)
+set_summary (E2kProperties *props,
+             ECalComponent *comp)
 {
 	static ECalComponentText summary;
 
@@ -118,7 +125,8 @@ set_summary (E2kProperties *props, ECalComponent *comp)
 }
 
 static void
-set_priority (E2kProperties *props, ECalComponent *comp)
+set_priority (E2kProperties *props,
+              ECalComponent *comp)
 {
 	gint *priority, value = 0;
 
@@ -138,7 +146,8 @@ set_priority (E2kProperties *props, ECalComponent *comp)
 }
 
 static void
-set_sensitivity (E2kProperties *props, ECalComponent *comp)
+set_sensitivity (E2kProperties *props,
+                 ECalComponent *comp)
 {
 	ECalComponentClassification classif;
 	gint sensitivity;
@@ -217,7 +226,8 @@ convert_to_utc (ECalComponentDateTime *dt)
 }
 
 static void
-set_dtstart (E2kProperties *props, ECalComponent *comp)
+set_dtstart (E2kProperties *props,
+             ECalComponent *comp)
 {
 	ECalComponentDateTime dt;
 	gchar *dtstart_str;
@@ -235,7 +245,8 @@ set_dtstart (E2kProperties *props, ECalComponent *comp)
 }
 
 static void
-set_due_date (E2kProperties *props, ECalComponent *comp)
+set_due_date (E2kProperties *props,
+              ECalComponent *comp)
 {
 	ECalComponentDateTime dt;
 	gchar *due_str;
@@ -264,7 +275,8 @@ icaltime_to_e2k_time (struct icaltimetype *itt)
 }
 
 static void
-set_date_completed (E2kProperties *props, ECalComponent *comp)
+set_date_completed (E2kProperties *props,
+                    ECalComponent *comp)
 {
 	struct icaltimetype *itt;
 	gchar *tstr;
@@ -285,7 +297,8 @@ set_date_completed (E2kProperties *props, ECalComponent *comp)
 }
 
 static void
-set_status (E2kProperties *props, ECalComponent *comp)
+set_status (E2kProperties *props,
+            ECalComponent *comp)
 {
 	icalproperty_status ical_status;
 	gint status;
@@ -318,7 +331,8 @@ set_status (E2kProperties *props, ECalComponent *comp)
 }
 
 static void
-set_percent (E2kProperties *props, ECalComponent *comp)
+set_percent (E2kProperties *props,
+             ECalComponent *comp)
 {
 	gint *percent;
 	gfloat res;
@@ -334,7 +348,8 @@ set_percent (E2kProperties *props, ECalComponent *comp)
 }
 
 static void
-set_categories (E2kProperties *props, ECalComponent *comp)
+set_categories (E2kProperties *props,
+                ECalComponent *comp)
 {
 	GSList *categories;
 	GSList *sl;
@@ -359,7 +374,8 @@ set_categories (E2kProperties *props, ECalComponent *comp)
 }
 
 static void
-set_url (E2kProperties *props, ECalComponent *comp)
+set_url (E2kProperties *props,
+         ECalComponent *comp)
 {
 	const gchar *url;
 
@@ -371,7 +387,8 @@ set_url (E2kProperties *props, ECalComponent *comp)
 }
 
 static void
-update_props (ECalComponent *comp, E2kProperties **properties)
+update_props (ECalComponent *comp,
+              E2kProperties **properties)
 {
 	E2kProperties *props = *properties;
 
@@ -436,10 +453,15 @@ get_summary (ECalComponent *comp)
 }
 
 static gint
-put_body (ECalComponent *comp, E2kContext *ctx, E2kOperation *op,
-         const gchar *uri, const gchar *from_name, const gchar *from_addr,
-	 const gchar *attach_body, const gchar *boundary,
-         gchar **repl_uid)
+put_body (ECalComponent *comp,
+          E2kContext *ctx,
+          E2kOperation *op,
+          const gchar *uri,
+          const gchar *from_name,
+          const gchar *from_addr,
+          const gchar *attach_body,
+          const gchar *boundary,
+          gchar **repl_uid)
 
 {
 	GSList *desc_list;
@@ -979,8 +1001,10 @@ get_changed_tasks (ECalBackendExchange *cbex)
 
 /* folder subscription notify callback */
 static void
-notify_changes (E2kContext *ctx, const gchar *uri,
-                     E2kContextChangeType type, gpointer user_data)
+notify_changes (E2kContext *ctx,
+                const gchar *uri,
+                E2kContextChangeType type,
+                gpointer user_data)
 {
 
 	ECalBackendExchange *ecalbex = E_CAL_BACKEND_EXCHANGE (user_data);
@@ -993,19 +1017,22 @@ notify_changes (E2kContext *ctx, const gchar *uri,
 }
 
 static void
-authenticate_user_task (ECalBackendSync *backend, GCancellable *cancellable, ECredentials *credentials, GError **perror)
+authenticate_user_task (ECalBackendSync *backend,
+                        GCancellable *cancellable,
+                        ECredentials *credentials,
+                        GError **perror)
 {
 	GThread *thread = NULL;
 	GError *error = NULL;
 	ECalBackendExchangeTasks *cbext = E_CAL_BACKEND_EXCHANGE_TASKS (backend);
 
-	E_CAL_BACKEND_SYNC_CLASS (parent_class)->authenticate_user_sync (backend, cancellable, credentials, &error);
+	E_CAL_BACKEND_SYNC_CLASS (e_cal_backend_exchange_tasks_parent_class)->authenticate_user_sync (backend, cancellable, credentials, &error);
 	if (error) {
 		g_propagate_error (perror, error);
 		return;
 	}
 
-	if (!e_cal_backend_is_online (E_CAL_BACKEND (backend))) {
+	if (!e_backend_get_online (E_BACKEND (backend))) {
 		d(printf ("ECBEC : calendar is offline\n"));
 		return;
 	}
@@ -1033,7 +1060,10 @@ authenticate_user_task (ECalBackendSync *backend, GCancellable *cancellable, ECr
 }
 
 static void
-refresh_task (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable, GError **perror)
+refresh_task (ECalBackendSync *backend,
+              EDataCal *cal,
+              GCancellable *cancellable,
+              GError **perror)
 {
 	g_return_if_fail (E_IS_CAL_BACKEND_EXCHANGE (backend));
 
@@ -1047,8 +1077,13 @@ struct _cb_data {
 };
 
 static void
-create_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable,
-		    const gchar *calobj, gchar **return_uid, gchar **new_object, GError **error)
+create_task_object (ECalBackendSync *backend,
+                    EDataCal *cal,
+                    GCancellable *cancellable,
+                    const gchar *calobj,
+                    gchar **return_uid,
+                    icalcomponent **new_icalcomp,
+                    GError **error)
 {
 	ECalBackendExchange *ecalbex;
 	E2kProperties *props;
@@ -1072,7 +1107,7 @@ create_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cance
 
 	e_return_data_cal_error_if_fail (calobj != NULL, InvalidArg);
 
-	if (!e_cal_backend_is_online (E_CAL_BACKEND (backend))) {
+	if (!e_backend_get_online (E_BACKEND (backend))) {
 		d(printf ("tasks are offline\n"));
 		g_propagate_error (error, EDC_ERROR (RepositoryOffline));
 		return;
@@ -1177,8 +1212,8 @@ create_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cance
 
 	update_props (comp, &props);
 	e_cal_component_commit_sequence (comp);
-	*new_object = e_cal_component_get_as_string (comp);
-	if (!*new_object) {
+	*new_icalcomp = icalcomponent_new_clone (e_cal_component_get_icalcomponent (comp));
+	if (!*new_icalcomp) {
 		g_object_unref (comp);
 		g_free (from_name);
 		g_free (from_addr);
@@ -1186,7 +1221,7 @@ create_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cance
 		return;
 	}
 
-	real_icalcomp = icalparser_parse_string (*new_object);
+	real_icalcomp = icalcomponent_new_clone (*new_icalcomp);
 
 	e2kctx = exchange_account_get_context (ecalbex->account);
 	status = e_folder_exchange_proppatch_new (ecalbex->folder, NULL,
@@ -1216,13 +1251,18 @@ create_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cance
 }
 
 static void
-modify_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable,
-	       const gchar *calobj, CalObjModType mod,
-	       gchar **old_object, gchar **new_object, GError **error)
+modify_task_object (ECalBackendSync *backend,
+                    EDataCal *cal,
+                    GCancellable *cancellable,
+                    const gchar *calobj,
+                    CalObjModType mod,
+                    icalcomponent **old_icalcomp,
+                    icalcomponent **new_icalcomp,
+                    GError **error)
 {
 	ECalBackendExchangeTasks *ecalbextask;
 	ECalBackendExchangeComponent *ecalbexcomp;
-	ECalComponent *cache_comp, *new_comp;
+	ECalComponent *new_comp;
 	ECalBackendExchange *ecalbex;
 	E2kProperties *props;
 	icalcomponent *icalcomp;
@@ -1242,7 +1282,7 @@ modify_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cance
 	e_return_data_cal_error_if_fail (E_IS_CAL_BACKEND_EXCHANGE_TASKS (ecalbextask), InvalidArg);
 	e_return_data_cal_error_if_fail (calobj != NULL, InvalidArg);
 
-	if (!e_cal_backend_is_online (E_CAL_BACKEND (backend))) {
+	if (!e_backend_get_online (E_BACKEND (backend))) {
 		d(printf ("tasks are offline\n"));
 		g_propagate_error (error, EDC_ERROR (RepositoryOffline));
 		return;
@@ -1278,10 +1318,7 @@ modify_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cance
 		return;
 	}
 
-	cache_comp = e_cal_component_new ();
-	e_cal_component_set_icalcomponent (cache_comp, icalcomponent_new_clone (ecalbexcomp->icomp));
-	*old_object = e_cal_component_get_as_string (cache_comp);
-	g_object_unref (cache_comp);
+	*old_icalcomp = icalcomponent_new_clone (ecalbexcomp->icomp);
 
 	e_cal_backend_exchange_cache_unlock (ecalbex);
 
@@ -1344,8 +1381,11 @@ modify_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cance
 }
 
 static void
-receive_task_objects (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable,
-                 const gchar *calobj, GError **error)
+receive_task_objects (ECalBackendSync *backend,
+                      EDataCal *cal,
+                      GCancellable *cancellable,
+                      const gchar *calobj,
+                      GError **error)
 {
 	ECalBackendExchangeTasks *ecalbextask;
 	ECalBackendExchange *cbex;
@@ -1362,7 +1402,7 @@ receive_task_objects (ECalBackendSync *backend, EDataCal *cal, GCancellable *can
 	e_return_data_cal_error_if_fail (E_IS_CAL_BACKEND_EXCHANGE_TASKS (ecalbextask), InvalidArg);
 	e_return_data_cal_error_if_fail (calobj != NULL, InvalidArg);
 
-	if (!e_cal_backend_is_online (E_CAL_BACKEND (backend))) {
+	if (!e_backend_get_online (E_BACKEND (backend))) {
 		d(printf ("tasks are offline\n"));
 		g_propagate_error (error, EDC_ERROR (RepositoryOffline));
 		return;
@@ -1393,34 +1433,40 @@ receive_task_objects (ECalBackendSync *backend, EDataCal *cal, GCancellable *can
 
 		e_cal_backend_exchange_cache_lock (cbex);
 		if (get_exchange_comp (E_CAL_BACKEND_EXCHANGE (ecalbextask), uid)) {
-			gchar *old_object;
+			icalcomponent *old_icalcomp = NULL, *new_icalcomp = NULL;
 
 			e_cal_backend_exchange_cache_unlock (cbex);
-			modify_task_object (backend, cal, cancellable, calobj, CALOBJ_MOD_THIS, &old_object, NULL, &err);
+			modify_task_object (backend, cal, cancellable, calobj, CALOBJ_MOD_THIS, &old_icalcomp, &new_icalcomp, &err);
 			if (err) {
 				g_free (rid);
 				g_propagate_error (error, err);
 				return;
 			}
 
-			e_cal_backend_notify_object_modified (E_CAL_BACKEND (backend), old_object, calobj);
-			g_free (old_object);
+			e_cal_backend_notify_component_modified (E_CAL_BACKEND (backend), old_icalcomp, new_icalcomp);
+			if (old_icalcomp)
+				icalcomponent_free (old_icalcomp);
+			if (new_icalcomp)
+				icalcomponent_free (new_icalcomp);
 		} else {
-			gchar *returned_uid, *new_object = NULL;
+			gchar *returned_uid;
+			icalcomponent *new_icalcomp = NULL;
 
 			e_cal_backend_exchange_cache_unlock (cbex);
-			calobj = (gchar *) icalcomponent_as_ical_string_r (subcomp);
-			create_task_object (backend, cal, cancellable, calobj, &returned_uid, &new_object, &err);
+			calobj = icalcomponent_as_ical_string_r (subcomp);
+			create_task_object (backend, cal, cancellable, calobj, &returned_uid, &new_icalcomp, &err);
 			g_free (calobj);
 			if (err) {
-				g_free (new_object);
+				if (new_icalcomp)
+					icalcomponent_free (new_icalcomp);
 				g_free (rid);
 				g_propagate_error (error, err);
 				return;
 			}
 
-			e_cal_backend_notify_object_created (E_CAL_BACKEND (backend), new_object);
-			g_free (new_object);
+			e_cal_backend_notify_component_created (E_CAL_BACKEND (backend), new_icalcomp);
+			if (new_icalcomp)
+				icalcomponent_free (new_icalcomp);
 		}
 		g_free (rid);
 	}
@@ -1429,19 +1475,24 @@ receive_task_objects (ECalBackendSync *backend, EDataCal *cal, GCancellable *can
 }
 
 static void
-remove_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable,
-	       const gchar *uid, const gchar *rid, CalObjModType mod,
-	       gchar **old_object, gchar **object, GError **error)
+remove_task_object (ECalBackendSync *backend,
+                    EDataCal *cal,
+                    GCancellable *cancellable,
+                    const gchar *uid,
+                    const gchar *rid,
+                    CalObjModType mod,
+                    icalcomponent **old_icalcomp,
+                    icalcomponent **new_icalcomp,
+                    GError **error)
 {
 	ECalBackendExchange *ecalbex = E_CAL_BACKEND_EXCHANGE (backend);
 	ECalBackendExchangeComponent *ecalbexcomp;
-	ECalComponent *comp;
 	E2kContext *ctx;
 	E2kHTTPStatus status;
 
 	e_return_data_cal_error_if_fail (E_IS_CAL_BACKEND_EXCHANGE (ecalbex), InvalidArg);
 
-	if (!e_cal_backend_is_online (E_CAL_BACKEND (backend))) {
+	if (!e_backend_get_online (E_BACKEND (backend))) {
 		d(printf ("tasks are offline\n"));
 		g_propagate_error (error, EDC_ERROR (RepositoryOffline));
 		return;
@@ -1456,10 +1507,7 @@ remove_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cance
 		return;
 	}
 
-	comp = e_cal_component_new ();
-	e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (ecalbexcomp->icomp));
-	*old_object = e_cal_component_get_as_string (comp);
-	g_object_unref (comp);
+	*old_icalcomp = icalcomponent_new_clone (icalcomponent_new_clone (ecalbexcomp->icomp));
 
 	e_cal_backend_exchange_cache_unlock (ecalbex);
 
@@ -1474,21 +1522,6 @@ remove_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cance
 	g_propagate_error (error, EDC_ERROR_HTTP_STATUS (status));
 }
 
-static void
-init (ECalBackendExchangeTasks *cbext)
-{
-	cbext->priv = g_new0 (ECalBackendExchangeTasksPrivate, 1);
-
-	cbext->priv->mutex = g_mutex_new ();
-	cbext->priv->is_loaded = FALSE;
-}
-
-static void
-dispose (GObject *object)
-{
-	G_OBJECT_CLASS (parent_class)->dispose (object);
-}
-
 static void
 finalize (GObject *object)
 {
@@ -1502,26 +1535,33 @@ finalize (GObject *object)
 
 	g_free (cbext->priv);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (e_cal_backend_exchange_tasks_parent_class)->finalize (object);
 }
 
 static void
-class_init (ECalBackendExchangeTasksClass *klass)
+e_cal_backend_exchange_tasks_class_init (ECalBackendExchangeTasksClass *class)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	ECalBackendSyncClass *sync_class = E_CAL_BACKEND_SYNC_CLASS (klass);
+	GObjectClass *object_class;
+	ECalBackendSyncClass *sync_class;
 
-	parent_class = g_type_class_peek_parent (klass);
+	object_class = G_OBJECT_CLASS (class);
+	object_class->finalize = finalize;
 
+	sync_class = E_CAL_BACKEND_SYNC_CLASS (class);
 	sync_class->authenticate_user_sync = authenticate_user_task;
 	sync_class->refresh_sync = refresh_task;
 	sync_class->create_object_sync = create_task_object;
 	sync_class->modify_object_sync = modify_task_object;
 	sync_class->remove_object_sync = remove_task_object;
 	sync_class->receive_objects_sync = receive_task_objects;
-
-	object_class->dispose = dispose;
-	object_class->finalize = finalize;
 }
 
-E2K_MAKE_TYPE (e_cal_backend_exchange_tasks, ECalBackendExchangeTasks, class_init, init, PARENT_TYPE)
+static void
+e_cal_backend_exchange_tasks_init (ECalBackendExchangeTasks *cbext)
+{
+	cbext->priv = g_new0 (ECalBackendExchangeTasksPrivate, 1);
+
+	cbext->priv->mutex = g_mutex_new ();
+	cbext->priv->is_loaded = FALSE;
+}
+
